@@ -1,21 +1,32 @@
 import asyncio
+from dataclasses import dataclass, field
 from http import HTTPStatus
 import json
-from typing import Any, AsyncIterator, Dict
+from typing import Any, AsyncIterator, Dict, List
 
 import aiohttp
 from graphql import OperationType
 from rath.operation import GraphQLException, GraphQLResult, Operation
 from rath.links.base import AsyncTerminatingLink
 from rath.links.errors import AuthenticationError
+import logging
+
+logger = logging.getLogger(__name__)
 
 
+@dataclass
 class AIOHttpLink(AsyncTerminatingLink):
+    url: str
+    auth_errors: List[HTTPStatus] = field(
+        default_factory=lambda: (HTTPStatus.FORBIDDEN,)
+    )
+    _session = None
 
-    auth_errors = [HTTPStatus.FORBIDDEN]
+    async def __aenter__(self) -> None:
+        self._session = await aiohttp.ClientSession().__aenter__()
 
-    def __init__(self, url: str = "") -> None:
-        self.url = url
+    async def __aexit__(self, *args, **kwargs) -> None:
+        await self._session.__aexit__(*args, **kwargs)
 
     async def aquery(self, operation: Operation) -> GraphQLResult:
         payload = {"query": operation.document}
@@ -52,35 +63,30 @@ class AIOHttpLink(AsyncTerminatingLink):
             payload["variables"] = operation.variables
             post_kwargs = {"json": payload}
 
-        async with aiohttp.ClientSession(headers=operation.context.headers) as session:
-            try:
-                async with session.post(self.url, **post_kwargs) as response:
+        async with self._session.post(
+            self.url, headers=operation.context.headers, **post_kwargs
+        ) as response:
 
-                    if response.status == HTTPStatus.OK:
-                        result = await response.json()
+            if response.status == HTTPStatus.OK:
+                result = await response.json()
 
-                    if response.status in self.auth_errors:
-                        raise AuthenticationError(
-                            f"Token Expired Error {operation.context.headers}"
-                        )
+            if response.status in self.auth_errors:
+                raise AuthenticationError(
+                    f"Token Expired Error {operation.context.headers}"
+                )
 
-                    json_response = await response.json()
+            json_response = await response.json()
 
-                    if "errors" in json_response:
-                        raise GraphQLException(
-                            "\n".join([e["message"] for e in json_response["errors"]])
-                        )
+            if "errors" in json_response:
+                raise GraphQLException(
+                    "\n".join([e["message"] for e in json_response["errors"]])
+                )
 
-                    if "data" not in json_response:
+            if "data" not in json_response:
 
-                        raise Exception(
-                            f"Response does not contain data {json_response}"
-                        )
+                raise Exception(f"Response does not contain data {json_response}")
 
-                    return GraphQLResult(data=json_response["data"])
-
-            except aiohttp.client_exceptions.InvalidURL as e:
-                raise Exception(f"Invalid URL {self.url}") from e
+            return GraphQLResult(data=json_response["data"])
 
     async def asubscribe(self, operation: Operation) -> AsyncIterator[GraphQLResult]:
         if operation.node.operation == OperationType.SUBSCRIPTION:
